@@ -3,7 +3,7 @@ __all__ = ["TinyMCE"]
 import re
 import pkg_resources
 
-from turbojson.jsonify import jsonify
+from turbojson.jsonify import encode
 from turbogears.widgets import JSSource, JSLink, TextArea, WidgetDescription, \
                                register_static_directory
 from turbogears.validators import FancyValidator
@@ -16,14 +16,6 @@ register_static_directory("tinymce", js_dir)
 
 
 
-# work around a possible simplejson bug. True gets jsonified into 'True' and
-# browsers barf as it should be 'true'
-jsonify.when(
-    """obj is True and isinstance(obj, bool)""")(lambda obj: "true")
-jsonify.when(
-    """obj is False and isinstance(obj, bool)""")(lambda obj: "false")
-
-
 
 
 class HTMLCleaner(FancyValidator):
@@ -76,7 +68,7 @@ class TinyMCE(TextArea):
     def update_data(self, d):
         super(TinyMCE, self).update_data(d)
         d['mce_options']['elements'] = d['field_id']
-        d['TinyMCEInit'] = "tinyMCE.init(%s);" % jsonify(d['mce_options'])
+        d['TinyMCEInit'] = "tinyMCE.init(%s);" % encode(d['mce_options'])
 
 
 
